<?php
/*
Plugin Name: J. BTON 's  Recent Posts mu-plugin for WordPress MU Ver.2.0
Plugin URI: http://bton.papalabs.com/?p=965
Description: Retrieves a list of the most recent posts in a WordPress MU installation.
Author: J. bton
Author URI: http://bton.papalabs.com/
Description: Retrieves a highly customizable list of the most recent sitewide posts in a WordPress MU installation. Automatically excludes blog ID 1 (main blog), and post ID 1 (first "Hello World" posts of new blogs). 
*/
/*
Parameter explanations
$how_many: how many recent posts are being displayed
$how_long: time frame to choose recent posts from (in days)
$cate: category ID to be selected
$limit: how many posts should be displayed from each category
$titleOnly: true (only title of post is displayed) OR false (title of post and name of blog are displayed)
$begin_wrap: customise the start html code to adapt to different themes
$optmask: bitmask for various display options (default: 255)
	DISPLAY OPTIONS BITMASK
	1;  // gravatar
	2;  // date
	4;  // author name
	8;  // comment count
	16; // blog name
	32; // post name
	64; // post excerpt
	128; // excerpt capitalization
$exc_size: size of excerpt in words (default: 30)
$end_wrap: customise the end html code to adapt to different themes

Sample call:
1)You can edit the palameter in this plugin code L76,
			function ahp_recent_posts($how_many=9, $how_long=30, $cate=5, $limit=3, $titleOnly=false, $optmask=255, $exc_size=30, $begin_wrap='<li class="pageposts_list">', $end_wrap='</li>') {
and call the function in your template file like this...
			<ul><?php bton_recent_posts(); ?></ul>
2)If you want to call the parameter in your each code of the template,
change L75 --> delate '//' from this code.
			function ahp_recent_posts($how_many, $how_long, $cate, $limit, $titleOnly, $optmask, $exc_size, $begin_wrap, $end_wrap) {
and coment out L76.
			//function ahp_recent_posts($how_many=9, $how_long=30, $cate=5, $limit=3, $titleOnly=false, $optmask=255, $exc_size=30, $begin_wrap='<li class="pageposts_list">', $end_wrap='</li>') {
So, you can set each parameter in your template
bton_recent_posts(9, 30, 5, 3, true, 255, 30, '<li class="pageposts_list">', '</li>'); >> total 9 most recent entries over the past 30 days, from cateID 5, 3 entries from each blog, displaying titles only
 write code in template like this...
			<ul><?php bton_recent_posts(9, 30, 5, 3, true, 255, 30, '<li class="pageposts_list">', '</li>'); ?></ul>
And you can also add style in your css files like this.
li.pageposts_list {list-mark-style:none;}
span.pageposts_cont{font-size:small; color:#333;}
span.pageposts_date {font-size:x-small; color:#ccc;}
span.pageposts_author {font-size:x-small; color:#ccc;}
span.pageposts_comment {font-size:x-small; color:#ccc;}
span.pageposts_blog {font-size:x-small; color:#ccc;}
span.pageposts_title {font-size:small; color:#333;}
*/
/*
Version: 2.0
Update Author: J. bton
Update Author URI: http://bton.papalabs.com/

**ORIGINAL CHANGELOG**
Version 0.6
Update Author: Aziz Poonawalla
Update Author URI: http://metablog.us
Version: 0.32
Update Author: G. Morehouse
Update Author URI: http://wiki.evernex.com/index.php?title=Wordpress_MU_sitewide_recent_posts_plugin
Version: 0.31
Update Author: Sven Laqua
Update Author URI: http://www.sl-works.de/
Version: 0.3
Author: Ron Rennick
Author URI: http://atypicalhomeschool.net/
*/


//function bton_recent_posts($how_many, $how_long, $cate, $limit, $titleOnly, $optmask, $exc_size, $begin_wrap, $end_wrap) {
function bton_recent_posts($how_many=9, $how_long=30, $cate=5, $limit=3, $titleOnly=false, $optmask=255, $exc_size=30, $begin_wrap='<li class="pageposts_list">', $end_wrap='</li>') {
	global $wpdb;
	$counter = 0;	
	
	// EDIT THESE TO CUSTOMIZE THE OUTPUT
	$debug = 0;
	$blog_prefix = "@";
	$post_prefix = " | ";
	$auth_prefix = ' by ';
	$com_prefix = ' | ';
	$date_format = 'D M jS, Y'; //Y.n.j =2009.1.1
	$grav_size = 24;
	
	// DISPLAY OPTIONS BITMASK
	$grav_flag = 1;  // gravatar
	$date_flag = 2;  // date
	$auth_flag = 4;  // author name
	$com_flag  = 8;  // comment count
	$name_flag = 16; // blog name	
	$post_flag = 32; // post name	
	$exc_flag  = 64; // post excerpt
	$cap_flag  = 128; // excerpt capitalization
	
	// set the various option flags
	if ($optmask & $grav_flag) { $use_grav = 1; } else { $use_grav = 0; } 
	if ($optmask & $date_flag) { $use_date = 1; } else { $use_date = 0; } 
	if ($optmask & $auth_flag) { $use_auth = 1; } else { $use_auth = 0; } 
	if ($optmask & $com_flag)  { $use_com  = 1; } else { $use_com = 0;  } 
	if ($optmask & $name_flag) { $use_name = 1; } else { $use_name = 0; } 
	if ($optmask & $post_flag) { $use_post = 1; } else { $use_post = 0; } 
	if ($optmask & $exc_flag)  { $use_exc  = 1; } else { $use_exc = 0;  } 
	if ($optmask & $cap_flag)  { $use_cap  = 1; } else { $use_cap = 0;  } 
	
	// debug block
	if ($debug) { 
		echo '<hr>'.'opt = '.$optmask.': grav = '.$use_grav.', date = '.$use_date
		.', auth = '.$use_auth.', use_com = '.$use_com.', use_name = '.$use_name
		.', use_post = '.$use_post.', use_exc = '.$use_exc.', use_cap = '.$use_cap;
	}

	// get a list of blogs in order of most recent update. show only public and nonarchived/spam/mature/deleted
	$blogs = $wpdb->get_col("
		SELECT blog_id 
		FROM $wpdb->blogs 
		WHERE public = '1' 
		AND archived = '0' 
		AND mature = '0' 
		AND spam = '0' 
		AND deleted = '0' 
		AND blog_id != '1' 
		AND last_updated >= DATE_SUB(CURRENT_DATE(), INTERVAL $how_long DAY)
		ORDER BY last_updated DESC");

	if ($blogs) {
		
		foreach ($blogs as $blog) {

			// we need _posts, _comments, and _options tables for this to work
			$blogOptionsTable = "wp_".$blog."_options";
		    $blogPostsTable = "wp_".$blog."_posts";
		    $blogCommentsTable = "wp_".$blog."_comments";
			$blogRelTable = "wp_".$blog."_term_relationships";
			$blogTermTable = "wp_".$blog."_term_taxonomy";
							
			// debug block
			if ($debug) { 
				echo '<hr>processing blog '.$blog.' = <a href="'.
				$options[0]->option_value.'">'.$options[1]->option_value.'</a><br />';
			}

		// we fetch the title and ID for the latest post
		$querypost ="
		SELECT T1.ID, T1.post_title, T1.post_content, T1.post_date, T1.guid, T4.display_name, T4.user_email, T4.user_login, T3.term_id 
		FROM ($blogPostsTable AS T1 LEFT JOIN $blogRelTable AS T2 ON T1.ID = T2.object_id)
		LEFT JOIN $blogTermTable AS T3 ON T2.term_taxonomy_id = T3.term_taxonomy_id
		INNER JOIN wp_users AS T4 ON T1.post_author = T4.ID
		WHERE post_status = 'publish' 
		AND post_type = 'post' 
		AND post_date >= DATE_SUB(CURRENT_DATE(), INTERVAL $how_long DAY)
		AND T3.term_id IN ($cate) 
		AND T1.ID > 1 
		ORDER BY post_date DESC
		LIMIT $limit";
		$thispost = $wpdb->get_results($querypost, OBJECT);


			// if it is found put it to the output
			if($thispost) {
			
			$i = 0;
				foreach ($thispost as $post) {
				// debug block
				if ($debugflag) {
					echo 'processing thispost ID = '.$thispost[$i]->ID.'<br />';
					echo 'post_title = '.$thispost[$i]->post_title.'<br />';
					echo 'post_content = '.$thispost[$i]->post_content.'<br />';
					echo 'post_date = '.$thispost[$i]->post_date.'<br />';
					echo 'display_name = '.$thispost[$i]->display_name.'<br />';
					echo 'user_email = '.$thispost[$i]->user_email.'<br />';
					echo 'user_login = '.$thispost[$i]->user_login.'<br />';
				}

				// get post ID
				$thispostID = $thispost[$i]->ID;
				
				// get permalink by ID.  check wp-includes/wpmu-functions.php
				$thispermalink = get_blog_permalink($blog, $thispostID);

					if ($titleOnly == false) {				
				// get blog name,  URL
				if ($use_name) { 
					
					$queryopt ="
					SELECT option_value 
					FROM $blogOptionsTable 
					WHERE option_name IN ('siteurl','blogname') 
					ORDER BY option_name DESC";
					$options = $wpdb->get_results($queryopt, OBJECT);

					$blog_link = $options[0]->option_value;
					$blog_name = $options[1]->option_value;
					$this_blogname = $blog_prefix.'<a href="'.$blog_link.'">'.$blog_name.'</a>';

				} else { $this_blogname = ''; }

				// get comments
				if ($use_com) {
					
					// sql query for all comments on the current post
					$querycomments ="SELECT comment_ID 
					FROM $blogCommentsTable 
					WHERE comment_post_ID = $thispostID";
					$thesecomments = $wpdb->get_results($querycomments, OBJECT);
										
					// count total number of comments
					$num_comments = sizeof($thesecomments);
					
					// pretty text
					if ($num_comments == 0) { $thiscomment = $com_prefix.'no comments'; }
					elseif ($num_comments == 1) { $thiscomment = $com_prefix.'one comment'; }
					else { $thiscomment = $com_prefix.$num_comments.' comments'; } 
					
				} else { $thiscomment = ''; }
									
				// get author
				if ($use_auth) { 
					$thisauthor = $auth_prefix.$thispost[$i]->display_name;
				} else { $thisauthor = ''; } 
				
				// get author's posts link 
				$thisuser = $thispost[$i]->user_login;
				$thisuser_url = $thisblog_link."author/".$thisuser;
				
				// get gravatar
				if ($use_grav) { 
					$grav_img = get_avatar( $thispost[$i]->user_email , $grav_size ); 
					$thisgravatar = '<a href="'.$thisuser_url.'">'.$grav_img.'</a>';
				} else { $thisgravatar = ''; }
				
				// get post date (nicely formatted)
				if ($use_date) { 
					$thisdate = date($date_format, strtotime( $thispost[$i]->post_date )) ; 					
				} else { $thisdate = ''; }
				
				// get post name 
				if ($use_post) { 
					$this_postname = $post_prefix.'<a href="'.$thispermalink.'">'.$thispost[$i]->post_title.'</a><br />';
				} else { $this_postname = ''; }
				
				if ($use_exc) { 

					if ($exc_size == 0) { $thisexcerpt = ''; }
					else { 
						// get post content and truncate to (numwords) words
						$thiscontent = strip_tags( $thispost[$i]->post_content );
						preg_match("/([\S]+\s*){0,$exc_size}/", $thiscontent, $regs);
						
						if ($use_cap) {
							// build the excerpt html block, capitalize first five words
							$trunc_content = explode( ' ', trim($regs[0]) , 6 );
							$exc_str = strtoupper($trunc_content[0]).' '
							.strtoupper($trunc_content[1]).' '
							.strtoupper($trunc_content[2]).' '
							.strtoupper($trunc_content[3]).' '
							.strtoupper($trunc_content[4]).' '
							.$trunc_content[5].'... ';
						} else { $exc_str = trim($regs[0]); } 
							
						$thisexcerpt = '<span class="pageposts_cont">'.$exc_str
						.'<a href="'.$thispermalink.'">'					
						.'&raquo;&raquo;MORE'.'</a></span>';
					}
				} else { $thisexcerpt = ''; }
												
					echo $begin_wrap
					.$thisgravatar
					.'<span class="pageposts_date">'.$thisdate.'</span>'.'<span class="pageposts_author">'.$thisauthor.'</span>'.'<span class="pageposts_comment">'.$thiscomment.'<br /></span>'
					.'<span class="pageposts_blog">'.$this_blogname.'</span>'
					.'<span class="pageposts_title">'.$this_postname.'</span>'
					.$thisexcerpt
					.$end_wrap;
					
					$counter++;
						} else {
						echo $begin_wrap.'<span class="pageposts_title">'.'<a href="'.$thispermalink
						.'">'.$thispost[$i]->post_title.'</a>'.'</span>'.$end_wrap;
						$counter++;
					} //if ($titleOnly == false) 
					$i ++ ;
				}
			} 											
			// don't go over the limit
			if($counter >= $how_many) { 
				break; 
			}
		}
	}
	else { 
		//echo "no recent posts meet the criteria...<br>";
	}
}
?>